@@ -99,6 +99,8 @@ class TestSecurity(unittest.TestCase):
         """
         from ZPublisher.Request import Request
         from ZPublisher.Response import Response
+
+        # Note: the next import fail in Python 3, because it needs ZServer.
         from ZPublisher.Publish import publish_module
 
         transaction.commit()
@@ -135,6 +137,14 @@ class TestSecurity(unittest.TestCase):
         return ResponseWrapper(response, outstream, path)
 
     def test_put_gives_401(self):
+        try:
+            # pkg_resources.get_distribution("ZServer") is not good enough,
+            # because ZServer may be included in the Zope2 package.
+            import ZServer  # noqa
+        except ImportError:
+            print("Ignoring PUT request method tests, as we miss the ZServer.")
+            return
+
         login(self.portal, TEST_USER_NAME)
         self.portal.invokeFactory("Collection", id="collection")
         self.portal.invokeFactory("Document", id="page")
@@ -148,6 +158,13 @@ class TestSecurity(unittest.TestCase):
         page = self.portal.page
         logout()
 
+        # from zope.publisher.browser import TestRequest
+
+        # import pdb; pdb.set_trace()
+        # request = TestRequest(request_method="PUT")
+        # collection.REQUEST = request
+        # x = collection()
+
         path = "/" + collection.absolute_url(relative=True)
         response = self.publish(path=path, env={}, request_method="PUT")
         self.assertEqual(response.getStatus(), 401)
